import createUUID from 'uuid/v4';
import {
  isnil,
  iso8601,
  required,
  string,
  uuid,
} from 'vue-mc/validation';

import Model from './Model';

class Task extends Model {
  defaults() {
    return {
      id: createUUID(),
      created: new Date().toISOString(),
      title: '',
      type_: '',
    };
  }

  mutations() {
    return {
      id: id => String(id) || null,
      created: created => new Date(created).toISOString(),
      name: String,
      type_: String,
    };
  }

  validation() {
    return {
      id: uuid.or(isnil),
      created: iso8601,
      title: required.and(string),
      type_: required.and(string),
    };
  }

  routes() {
    return {
      save: '/api/v1/task',
    };
  }
}


export default Task;
